@@ -61,7 +61,6 @@ def parser_config_file(config: easydict.EasyDict, config_file: str, cfg_updata:
         cfg = dict(cfg, **config.__dict__)
     else:
         cfg = dict(config.__dict__, **cfg)
-    cfg["config_file"] = config.config_file
     print_dict(cfg)
     cfg = easydict.EasyDict(cfg)
     return cfg
@@ -92,15 +91,18 @@ def load_config(config_file='config.yaml'):
     return config
 
 
-def save_config(data: dict, config_file='config.yaml'):
+def save_config(cfg: dict, config_file='config.yaml'):
     """保存yaml文件"""
+    if isinstance(cfg, easydict.EasyDict) or isinstance(cfg, argparse.Namespace):
+        cfg = cfg.__dict__
     fw = open(config_file, 'w', encoding='utf-8')
-    yaml.dump(data, fw)
+    yaml.dump(cfg, fw)
     return config_file
 
 
 def print_dict(dict_data, save_path=None):
     list_config = []
+    print("=" * 60)
     for key in dict_data:
         info = "{}: {}".format(key, dict_data[key])
         print(info)
@@ -109,6 +111,7 @@ def print_dict(dict_data, save_path=None):
         with open(save_path, "w") as f:
             for info in list_config:
                 f.writelines(info + "\n")
+    print("=" * 60)
 
 
 if __name__ == '__main__':
